<?php
/**
 * Siska Lite Theme Customizer
 *
 * @package Siska Lite
 */

/**
 * Add postMessage support for site title and description for the Theme Customizer.
 *
 * @param WP_Customize_Manager $wp_customize Theme Customizer object.
 */
function siska_lite_customize_register( $wp_customize ) {
	function siska_lite_sanitize_checkbox( $checked ) {
		// Boolean check.
		return ( ( isset( $checked ) && true == $checked ) ? true : false );
	}

	$wp_customize->get_setting( 'blogname' )->siska_lite         = 'postMessage';
	$wp_customize->get_setting( 'blogdescription' )->siska_lite  = 'postMessage';

	$wp_customize->selective_refresh->add_partial( 'blogname', array(
	    'selector' => '.site-name-desc a',
	    'render_callback' => 'siska-lite_customize_partial_blogname',
	) );

	$wp_customize->selective_refresh->add_partial( 'blogdescription', array(
	    'selector' => '.site-name-desc p',
	    'render_callback' => 'siska-lite_customize_partial_blogdescription',
	) );

	/*========================
	==	Theme Colors Start
	========================*/

	$wp_customize->add_setting('color_scheme', array(
		'default' => '#ff9a00',
		'sanitize_callback'	=> 'sanitize_hex_color',
	));
	
	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'color_scheme',array(
			'label' => __('Color Scheme','siska-lite'),
			'description'	=> __('Select theme main color from here.','siska-lite'),
			'section' => 'colors',
			'settings' => 'color_scheme'
		))
	);

	$wp_customize->add_setting('siska_headerbg-color', array(
		'default' => '#000000',
		'sanitize_callback'	=> 'sanitize_hex_color',
	));
	
	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'siska_headerbg-color',array(
			'label' => __('Header Background Color','siska-lite'),
			'description'	=> __('Select background color for header.','siska-lite'),
			'section' => 'colors',
			'settings' => 'siska_headerbg-color'
		))
	);

	$wp_customize->add_setting('siska_footer-color', array(
		'default' => '#ff9a00',
		'sanitize_callback'	=> 'sanitize_hex_color',
	));
	
	$wp_customize->add_control(
		new WP_Customize_Color_Control($wp_customize,'siska_footer-color',array(
			'label' => __('Footer Background Color','siska-lite'),
			'description'	=> __('Select background color for footer.','siska-lite'),
			'section' => 'colors',
			'settings' => 'siska_footer-color'
		))
	);

	/*========================
	==	Theme Colors End
	========================*/

	/*========================
	==	Top Header Start
	========================*/

	$wp_customize->add_section(
        'siska_top_header',
        array(
            'title' => __('Setting Up Top Header', 'siska-lite'),
            'priority' => null,
			'description'	=> __('Alter top header data of the theme.','siska-lite'),	
        )
    );

    $wp_customize->add_setting('siska_tp_head_mail',array(
		'sanitize_callback'	=> 'sanitize_text_field',
		'transport' => 'refresh'
	));

	$wp_customize->add_control('siska_tp_head_mail',array(
		'type'	=> 'text',
		'label'	=> __('Add Email Address here.','siska-lite'),
		'section'	=> 'siska_top_header'
	));

	$wp_customize->add_setting('siska_tp_head_tel',array(
		'sanitize_callback'	=> 'sanitize_text_field',
		'transport' => 'refresh'
	));

	$wp_customize->add_control('siska_tp_head_tel',array(
		'type'	=> 'text',
		'label'	=> __('Add Phone Number here.','siska-lite'),
		'section'	=> 'siska_top_header'
	));

	$wp_customize->add_setting('siska_tp_fb',array(
		'sanitize_callback'	=> 'esc_url_raw',
		'transport' => 'refresh'
	));

	$wp_customize->add_control('siska_tp_fb',array(
		'type'	=> 'url',
		'label'	=> __('Add facebook url here.','siska-lite'),
		'section'	=> 'siska_top_header'
	));

    $wp_customize->add_setting('siska_tp_tw',array(
		'sanitize_callback'	=> 'esc_url_raw',
		'transport' => 'refresh'
	));

	$wp_customize->add_control('siska_tp_tw',array(
		'type'	=> 'url',
		'label'	=> __('Add twitter url here.','siska-lite'),
		'section'	=> 'siska_top_header'
	));

	$wp_customize->add_setting('siska_tp_ins',array(
		'sanitize_callback'	=> 'esc_url_raw',
		'transport' => 'refresh'
	));

	$wp_customize->add_control('siska_tp_ins',array(
		'type'	=> 'url',
		'label'	=> __('Add instagram url here.','siska-lite'),
		'section'	=> 'siska_top_header'
	));

	$wp_customize->add_setting('siska_tp_in',array(
		'sanitize_callback'	=> 'esc_url_raw',
		'transport' => 'refresh'
	));

	$wp_customize->add_control('siska_tp_in',array(
		'type'	=> 'url',
		'label'	=> __('Add linkedin url here.','siska-lite'),
		'section'	=> 'siska_top_header'
	));

	$wp_customize->add_setting('siska_tp_gp',array(
		'sanitize_callback'	=> 'esc_url_raw',
		'transport' => 'refresh'
	));

	$wp_customize->add_control('siska_tp_gp',array(
		'type'	=> 'url',
		'label'	=> __('Add google plus url here.','siska-lite'),
		'section'	=> 'siska_top_header'
	));

	$wp_customize->add_setting('siska_tp_yt',array(
		'sanitize_callback'	=> 'esc_url_raw',
		'transport' => 'refresh'
	));

	$wp_customize->add_control('siska_tp_yt',array(
		'type'	=> 'url',
		'label'	=> __('Add youtube url here.','siska-lite'),
		'section'	=> 'siska_top_header'
	));

	$wp_customize->add_setting('siska_hide_tphead',array(
		'default' => true,
		'sanitize_callback' => 'siska_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	));	 

	$wp_customize->add_control( 'siska_hide_tphead', array(
		'settings' => 'siska_hide_tphead',
		'label'     => __('Check to hide top header','siska-lite'),
		'section'   => 'siska_top_header',
		'type'      => 'checkbox'
	));

	/*========================
	==	Top Header End
	========================*/
	
	/*========================
	==	Slider Start
	========================*/
	$wp_customize->add_section(
        'siska_theme_slider',
        array(
            'title' => __('Setting Up Theme Slider', 'siska-lite'),
            'priority' => null,
			'description'	=> __('Recommended image size (1600x900). Slider will work only when you select the static front page.','siska-lite'),	
        )
    );

    $wp_customize->add_setting('slidesmlttl',array(
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('slidesmlttl',array(
		'type'	=> 'text',
		'label'	=> __('Add sub title for all slides','siska-lite'),
		'section'	=> 'siska_theme_slider'
	));

	$wp_customize->add_setting('theme-slide1',array(
		'default' => '0',
		'capability' => 'edit_theme_options',
		'sanitize_callback'	=> 'absint'
	));

	$wp_customize->add_control('theme-slide1',array(
		'type'	=> 'dropdown-pages',
		'label'	=> __('Select page for slide one:','siska-lite'),
		'section'	=> 'siska_theme_slider'
	));	

	$wp_customize->add_setting('theme-slide2',array(
		'default' => '0',
		'capability' => 'edit_theme_options',	
		'sanitize_callback'	=> 'absint'
	));

	$wp_customize->add_control('theme-slide2',array(
		'type'	=> 'dropdown-pages',
		'label'	=> __('Select page for slide two:','siska-lite'),
		'section'	=> 'siska_theme_slider'
	));	

	$wp_customize->add_setting('theme-slide3',array(
		'default' => '0',
		'capability' => 'edit_theme_options',	
		'sanitize_callback'	=> 'absint'
	));

	$wp_customize->add_control('theme-slide3',array(
		'type'	=> 'dropdown-pages',
		'label'	=> __('Select page for slide three:','siska-lite'),
		'section'	=> 'siska_theme_slider'
	));	
	
	$wp_customize->add_setting('slide_read_more',array(
		'default'	=> __('','siska-lite'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('slide_read_more',array(
		'label'	=> __('Add slider link button text.','siska-lite'),
		'section'	=> 'siska_theme_slider',
		'setting'	=> 'slide_read_more',
		'type'	=> 'text'
	));
	
	$wp_customize->add_setting('hide_theme_slider',array(
		'default' => true,
		'sanitize_callback' => 'siska_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	)); 

	$wp_customize->add_control( 'hide_theme_slider', array(
	   'settings' => 'hide_theme_slider',
	   'section'   => 'siska_theme_slider',
	   'label'     => __('Check this to hide slider.','siska-lite'),
	   'type'      => 'checkbox'
    ));
	/*========================
	==	Slider End
	========================*/
	
	/*========================
	==	fisrt Section Start
	========================*/

	$wp_customize->add_section(
        'siska_intro_sec',
        array(
            'title' => __('Setting Up Introduction Section', 'siska-lite'),
            'priority' => null,
			'description'	=> __('Select pages for setting up first / Introduction section. This section will be displayed only when you select the static front page.','siska-lite'),	
        )
    );
	
	$wp_customize->add_setting('siska_intro_ttl',array(
		'default'	=> __('','siska-lite'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('siska_intro_ttl',array(
		'label'	=> __('Add sub title text here.','siska-lite'),
		'section'	=> 'siska_intro_sec',
		'setting'	=> 'siska_intro_ttl',
		'type'	=> 'text'
	));

    $wp_customize->add_setting('siska_intro',array(
		'default' => '0',
		'capability' => 'edit_theme_options',
		'sanitize_callback'	=> 'absint'
	));
	
	$wp_customize->add_control('siska_intro',array(
		'type'	=> 'dropdown-pages',
		'label'	=> __('Select page for 1st column','siska-lite'),
		'section'	=> 'siska_intro_sec'
	));
	
	$wp_customize->add_setting('siska_intro_more',array(
		'default'	=> __('','siska-lite'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('siska_intro_more',array(
		'label'	=> __('Add Read More text here.','siska-lite'),
		'section'	=> 'siska_intro_sec',
		'setting'	=> 'siska_intro_more',
		'type'	=> 'text'
	));
	
	$wp_customize->add_setting('siska_intro_hide',array(
		'default' => true,
		'sanitize_callback' => 'siska_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	)); 

	$wp_customize->add_control( 'siska_intro_hide', array(
	   'settings' => 'siska_intro_hide',
	   'section'   => 'siska_intro_sec',
	   'label'     => __('Check this to hide section.','siska-lite'),
	   'type'      => 'checkbox'
     ));

	/*========================
	==	First Section End
	========================*/
	
	/*========================
	==	Second Section Start
	========================*/
	$wp_customize->add_section(
        'siska_wedo_sec',
        array(
            'title' => __('Setting Up What We Do Section', 'siska-lite'),
            'priority' => null,
			'description'	=> __('Select pages for setting up second / what we do section. This section will be displayed only when you select the static front page.','siska-lite'),	
        )
    );

    $wp_customize->add_setting('siska_wedo_ttl',array(
		'default'	=> __('','siska-lite'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('siska_wedo_ttl',array(
		'label'	=> __('Add section title here','siska-lite'),
		'section'	=> 'siska_wedo_sec',
		'setting'	=> 'siska_wedo_ttl',
		'type'	=> 'text'
	));

	$wp_customize->add_setting('siska_wedo1',array(
		'default' => '0',
		'capability' => 'edit_theme_options',
		'sanitize_callback'	=> 'absint'
	));
	
	$wp_customize->add_control('siska_wedo1',array(
		'type'	=> 'dropdown-pages',
		'label'	=> __('Select page for 1st row','siska-lite'),
		'section'	=> 'siska_wedo_sec'
	));

	$wp_customize->add_setting('siska_wedo2',array(
		'default' => '0',
		'capability' => 'edit_theme_options',
		'sanitize_callback'	=> 'absint'
	));
	
	$wp_customize->add_control('siska_wedo2',array(
		'type'	=> 'dropdown-pages',
		'label'	=> __('Select page for 2nd row','siska-lite'),
		'section'	=> 'siska_wedo_sec'
	));

	$wp_customize->add_setting('siska_wedo_more',array(
		'default'	=> __('','siska-lite'),
		'sanitize_callback'	=> 'sanitize_text_field'
	));
	
	$wp_customize->add_control('siska_wedo_more',array(
		'label'	=> __('Add Read More text here.','siska-lite'),
		'section'	=> 'siska_wedo_sec',
		'setting'	=> 'siska_wedo_more',
		'type'	=> 'text'
	));

	$wp_customize->add_setting('siska_wedo_hide',array(
		'default' => true,
		'sanitize_callback' => 'siska_lite_sanitize_checkbox',
		'capability' => 'edit_theme_options',
	)); 

	$wp_customize->add_control( 'siska_wedo_hide', array(
	   'settings' => 'siska_wedo_hide',
	   'section'   => 'siska_wedo_sec',
	   'label'     => __('Check this to hide section.','siska-lite'),
	   'type'      => 'checkbox'
    ));

	/*========================
	==	Second Section End
	========================*/
	
}
add_action( 'customize_register', 'siska_lite_customize_register' );	

function siska_lite_css(){
		?>
        <style>
			a, 
			.tm_client strong,
			.postmeta a:hover,
			#sidebar ul li a:hover,
			.blog-post h3.entry-title,
			a.blog-more:hover,
			#commentform input#submit,
			input.search-submit,
			.blog-date .date,
			.sitenav ul li.current_page_item a,
			.sitenav ul li a:hover, 
			.sitenav ul li.current_page_item ul li a:hover,
			.site-name-desc p,
			.caption-holder h4,
			.caption-holder a.slide-button:hover,
			.read-more a:hover,
			.top-header a,
			.intro-left h4{
				color:<?php echo esc_attr(get_theme_mod('color_scheme','#ff9a00')); ?>;
			}
			.nivo-controlNav a.active{
				border-color:<?php echo esc_attr(get_theme_mod('color_scheme','#ff9a00')); ?>;
			}
			h3.widget-title,
			.nav-links .current,
			.nav-links a:hover,
			p.form-submit input[type="submit"],
			.social a:hover,
			.nivo-controlNav a.active,
			a.nivo-prevNav,
			a.nivo-nextNav,
			a.slide-button:before,
			a.slide-button:after,
			.read-more a:before,
			.read-more a:after,
			.top-header a:hover,
			h2.section_title:before{
				background-color:<?php echo esc_attr(get_theme_mod('color_scheme','#ff9a00')); ?>;
			}	
			#header,
			.sitenav ul li.menu-item-has-children:hover > ul,
			.sitenav ul li.menu-item-has-children:focus > ul,
			.sitenav ul li.menu-item-has-children.focus > ul{
				background-color:<?php echo esc_attr(get_theme_mod('siska_headerbg-color','#000000')); ?>;
			}
			.copyright-wrapper{
				background-color:<?php echo esc_attr(get_theme_mod('siska_footer-color','#ff9a00')); ?>;
			}
		</style>
	<?php }
add_action('wp_head','siska_lite_css');

function siska_lite_customize_preview_js() {
	wp_enqueue_script( 'siska-lite-customize-preview', get_template_directory_uri() . '/js/customize-preview.js', array( 'customize-preview' ), '20141216', true );
}
add_action( 'customize_preview_init', 'siska_lite_customize_preview_js' );